PyKEEN
======
PyKEEN (Python KnowlEdge EmbeddiNgs) is a package for training and evaluating knowledge graph embeddings (KGEs)
and is part of the KEEN-Universe.

The system has a modular architecture, and can be configured by the user through the command line interface.

Installation is as easy as getting the code from `PyPI <https://pypi.python.org/pypi/pykeen>`_ with
:code:`pip install pykeen`.

.. toctree::
   :maxdepth: 2
   :name: start

   overview
   installation
   train_and_evaluate
   summarize

.. toctree::
   :maxdepth: 2
   :caption: CLI Usage
   :name: cli

   cli/train_and_evaluate
   cli/inference

.. toctree::
   :maxdepth: 2
   :caption: Tutorial
   :name: tutorial

   train_and_evaluate
   hyper_parameter_optimization

.. toctree::
   :maxdepth: 2
   :caption: Reference
   :name: reference

   models

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
